Documentation — Django Grappelli v2.3.5 documentation

### Navigation

- index
- next |
- Django Grappelli v2.3.5 documentation »

# Documentation

A jazzy skin for the Django admin interface.

This documentation covers version 2.3.5 of Grappelli. Grappelli is a grid-based alternative/extension to the Django administration interface.

Note

Grappelli 2.3.5 requires Django 1.3. Grappelli is always developed against the lastest stable Django release and is NOT tested with Djangos trunk.

## Installation & Setup

- Quick start guide
  - Installation
  - Setup
  - Testing
- Customization
  - Available Settings
  - Collapsibles
  - Inline Sortables
  - Related Lookups
  - Autocomplete Lookups
  - Using TinyMCE

## Dashboard

- Dashboard Setup
  - Add `grappelli.dashboard` to your Installed Apps
  - Add context-processors
  - Create a custom Dashboard
  - Create custom Dashboards for multiple admin sites
- Dashboard API
  - The `Dashboard` class
  - The `DashboardModule` class
  - The `Group` class
  - The `LinkList` class
  - The `AppList` class
  - The `ModelList` class
  - The `RecentActions` class
  - The `Feed` class
- Dashboard Layout
- Extending the Dashboard

## Internals

- Templates
- Javascripts
  - Original JS
  - Grappelli JS

## Help

- FAQ
- Third Party Applications
- Troubleshooting
- Django Issues
- Grappelli 2.3.x Release Notes
- Changelog

## Code

https://github.com/sehmaschine/django-grappelli

## Discussion

Use the Grappelli Google Group to ask questions or discuss features.

### Navigation

- index
- next |
- Django Grappelli v2.3.5 documentation »